==> kdelibs-4.4.5.tbz: share/apps/cmake/modules/KDELibs4ToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDE4__kconfig_compiler" for configuration "release"
SET_PROPERTY(TARGET KDE4__kconfig_compiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__kconfig_compiler PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/bin/kconfig_compiler"
  )

# Import target "KDE4__kauth-policy-gen" for configuration "release"
SET_PROPERTY(TARGET KDE4__kauth-policy-gen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__kauth-policy-gen PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/kde4/libexec/kauth-policy-gen"
  )

# Import target "KDE4__meinproc4" for configuration "release"
SET_PROPERTY(TARGET KDE4__meinproc4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__meinproc4 PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/bin/meinproc4"
  )

# Import target "KDE4__makekdewidgets" for configuration "release"
SET_PROPERTY(TARGET KDE4__makekdewidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__makekdewidgets PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/bin/makekdewidgets"
  )

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)

==> kdelibs-4.7.3.tbz: share/apps/cmake/modules/KDELibs4ToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDE4__kconfig_compiler" for configuration "Release"
SET_PROPERTY(TARGET KDE4__kconfig_compiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__kconfig_compiler PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/bin/kconfig_compiler"
  )

# Import target "KDE4__kauth-policy-gen" for configuration "Release"
SET_PROPERTY(TARGET KDE4__kauth-policy-gen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__kauth-policy-gen PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/kde4/libexec/kauth-policy-gen"
  )

# Import target "KDE4__meinproc4" for configuration "Release"
SET_PROPERTY(TARGET KDE4__meinproc4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__meinproc4 PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/bin/meinproc4"
  )

# Import target "KDE4__makekdewidgets" for configuration "Release"
SET_PROPERTY(TARGET KDE4__makekdewidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4__makekdewidgets PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/bin/makekdewidgets"
  )

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)
